Index: include/gpu/vk/GrVkInterface.h |
diff --git a/include/gpu/vk/GrVkInterface.h b/include/gpu/vk/GrVkInterface.h |
index e36bfb1a023f98ff6147baed9faf45d707c09668..418aaae95851ed1cfcf12e1e7daae0c55200c9bc 100644 |
--- a/include/gpu/vk/GrVkInterface.h |
+++ b/include/gpu/vk/GrVkInterface.h |
@@ -5,17 +5,17 @@ |
* found in the LICENSE file. |
*/ |
-#ifndef GrRadInterface_DEFINED |
-#define GrRadInterface_DEFINED |
+#ifndef GrVkInterface_DEFINED |
+#define GrVkInterface_DEFINED |
#include "SkRefCnt.h" |
-#include "vulkan/vulkan.h" |
+#include "vk/GrVkDefines.h" |
//////////////////////////////////////////////////////////////////////////////// |
/** |
* The default interface is returned by GrVkDefaultInterface. This function's |
* implementation is platform-specific. |
*/ |
@@ -200,6 +200,15 @@ public: |
VkPtr<PFN_vkGetPhysicalDeviceSurfaceCapabilitiesKHR> fGetPhysicalDeviceSurfaceCapabilitiesKHR; |
VkPtr<PFN_vkGetPhysicalDeviceSurfaceFormatsKHR> fGetPhysicalDeviceSurfaceFormatsKHR; |
VkPtr<PFN_vkGetPhysicalDeviceSurfacePresentModesKHR> fGetPhysicalDeviceSurfacePresentModesKHR; |
+#if defined(VK_USE_PLATFORM_WIN32_KHR) |
bsalomon
2016/03/28 13:05:47
Will these be used in Ganesh proper or just in the
jvanverth1
2016/03/28 13:35:38
Sure, I could do that when I get the windowing goi
|
+ VkPtr<PFN_vkCreateWin32SurfaceKHR> fCreateWin32SurfaceKHR; |
+ VkPtr<PFN_vkGetPhysicalDeviceWin32PresentationSupportKHR> fGetPhysicalDeviceWin32PresentationSupportKHR; |
+#elif defined(VK_USE_PLATFORM_ANDROID_KHR) |
+ VkPtr<PFN_vkCreateAndroidSurfaceKHR> fCreateAndroidSurfaceKHR; |
+#elif defined(VK_USE_PLATFORM_XLIB_KHR) |
+ VkPtr<PFN_vkCreateXlibSurfaceKHR> fCreateXlibSurfaceKHR; |
+ VkPtr<PFN_vkGetPhysicalDeviceXlibPresentationSupportKHR> fGetPhysicalDeviceXlibPresentationSupportKHR; |
+#endif |
VkPtr<PFN_vkCreateSwapchainKHR> fCreateSwapchainKHR; |
VkPtr<PFN_vkDestroySwapchainKHR> fDestroySwapchainKHR; |
VkPtr<PFN_vkGetSwapchainImagesKHR> fGetSwapchainImagesKHR; |
@@ -5,17 +5,17 @@ |
//////////////////////////////////////////////////////////////////////////////// |
/** |
- * The default interface is returned by GrVkDefaultInterface. This function's |
+ * The default interface is returned by GrVkCreateInterface. This function's |
* implementation is platform-specific. |
*/ |